# Generated by Django 3.2.3 on 2021-05-26 14:10

from django.db import migrations, models
from oscar.models.fields import NullCharField


def null_child_voucher_names(apps, schema_editor):
    Voucher = apps.get_model("voucher", "Voucher")
    Voucher.objects.filter(parent__isnull=False).update(name=None)


def make_voucher_names_unique(apps, schema_editor):
    """
    Appends a number to non-unique voucher names.
    """
    Voucher = apps.get_model("voucher", "Voucher")
    vouchers = Voucher.objects.filter(parent__isnull=True).order_by("date_created")
    # Find vouchers with non-unique names
    vouchers_for_name = {}
    for voucher in vouchers:
        if voucher.name not in vouchers_for_name:
            vouchers_for_name[voucher.name] = []
        vouchers_for_name[voucher.name].append(voucher.id)
    # Change names for vouchers with non-unique names
    for voucher in vouchers:
        if len(vouchers_for_name[voucher.name]) > 1:
            voucher.name = "%s - %d" % (
                voucher.name,
                vouchers_for_name[voucher.name].index(voucher.id) + 1,
            )
            voucher.save()


class Migration(migrations.Migration):

    dependencies = [
        ("voucher", "0009_auto_20210216_1327"),
    ]

    operations = [
        # Allow name field to be null
        migrations.AlterField(
            model_name="voucher",
            name="name",
            field=NullCharField(
                verbose_name="Name",
                help_text="This will be shown in the checkout and basket once the voucher is entered",
                max_length=128,
            ),
        ),
        # Set child codes name field to null
        migrations.RunPython(null_child_voucher_names, migrations.RunPython.noop),
        # Make other voucher names unique
        migrations.RunPython(make_voucher_names_unique, migrations.RunPython.noop),
        # Add unique index to Voucher.name
        migrations.AlterField(
            model_name="voucher",
            name="name",
            field=NullCharField(
                verbose_name="Name",
                help_text="This will be shown in the checkout and basket once the voucher is entered",
                max_length=128,
                unique=True,
            ),
        ),
        # Remaining Oscar 3.1 changes
        migrations.RemoveField(
            model_name="voucherset",
            name="offer",
        ),
        migrations.AlterField(
            model_name="voucherset",
            name="name",
            field=models.CharField(max_length=100, unique=True, verbose_name="Name"),
        ),
    ]
